┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/panels/information/informationpanelcontent.cpp
diff options
context:
space:
mode:
authorMéven Car <[email protected]>2025-05-03 11:13:33 +0200
committerMéven Car <[email protected]>2025-06-28 11:55:38 +0200
commit58c48052c38e5bb4f6cf8047dc71e40cfbf04403 (patch)
tree155f7ae706eef26fe31f6f9b69ac0d3c6f3dbb5c /src/panels/information/informationpanelcontent.cpp
parent8216a67d58af0fd709bb3bfb8d0b6073b11cdfed (diff)
mediawidget: bind arrow keys to slide in media
Diffstat (limited to 'src/panels/information/informationpanelcontent.cpp')
-rw-r--r--src/panels/information/informationpanelcontent.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/panels/information/informationpanelcontent.cpp b/src/panels/information/informationpanelcontent.cpp
index 1ab57c0e7..134c5e056 100644
--- a/src/panels/information/informationpanelcontent.cpp
+++ b/src/panels/information/informationpanelcontent.cpp
@@ -211,9 +211,9 @@ void InformationPanelContent::refreshPreview()
const QString mimeType = m_item.mimetype();
const bool isAnimatedImage = m_preview->isAnimatedMimeType(mimeType);
m_isVideo = !isAnimatedImage && mimeType.startsWith(QLatin1String("video/"));
- bool usePhonon = m_isVideo || mimeType.startsWith(QLatin1String("audio/"));
+ bool useMedia = m_isVideo || mimeType.startsWith(QLatin1String("audio/"));
- if (usePhonon) {
+ if (useMedia) {
// change the cursor of the preview
m_preview->setCursor(Qt::PointingHandCursor);
m_preview->installEventFilter(m_mediaWidget);
@@ -221,7 +221,7 @@ void InformationPanelContent::refreshPreview()
m_mediaWidget->show();
// if the video is playing, has been paused or stopped
// we don't need to update the preview/phonon widget states
// unless the previewed file has changed,
// or the setting previewshown has changed
if ((m_mediaWidget->state() != QMediaPlayer::PlayingState && m_mediaWidget->state() != QMediaPlayer::PausedState
@@ -242,7 +242,7 @@ void InformationPanelContent::refreshPreview()
if (isAnimatedImage) {
m_preview->setAnimatedImageFileName(itemUrl.toLocalFile());
}
// When we don't need it, hide the phonon widget first to avoid flickering
m_mediaWidget->hide();
m_preview->show();
m_preview->removeEventFilter(m_mediaWidget);
@@ -221,7 +221,7 @@ void InformationPanelContent::refreshPreview()
m_mediaWidget->show();
// if the video is playing, has been paused or stopped
- // we don't need to update the preview/phonon widget states
+ // we don't need to update the preview/media widget states
// unless the previewed file has changed,
// or the setting previewshown has changed
@@ -242,7 +242,7 @@ void InformationPanelContent::refreshPreview()
m_preview->setAnimatedImageFileName(itemUrl.toLocalFile());
}
- // When we don't need it, hide the phonon widget first to avoid flickering
+ // When we don't need it, hide the media widget first to avoid flickering
m_mediaWidget->hide();
m_preview->show();